@@ -1,4 +1,4 @@
-#' General accessor function for RLum S4 class objects
+#' General accessors function for RLum S4 class objects
 #'
 #' Function calls object-specific get functions for RLum S4 class objects.
 #'
@@ -13,7 +13,7 @@
 #' of type [RLum-class]
 #'
 #' @param ... further arguments that will be passed to the object specific methods. For
-#' furter details on the supported arguments please see the class
+#' further details on the supported arguments please see the class
 #' documentation: [RLum.Data.Curve-class], [RLum.Data.Spectrum-class],
 #' [RLum.Data.Image-class], [RLum.Analysis-class] and [RLum.Results-class]
 #'
@@ -22,7 +22,7 @@
 #' @section Function version: 0.3.3
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [RLum.Data.Curve-class], [RLum.Data.Image-class],
 #'  [RLum.Data.Spectrum-class], [RLum.Analysis-class], [RLum.Results-class]
@@ -81,7 +81,7 @@ setMethod("get_RLum",
 
                 ##it might be the case the object already comes with empty objects, this would
                 ##cause a crash
-                if(class(object[[x]]) == "RLum.Analysis" && length(object[[x]]@records) == 0)
+                if(inherits(object[[x]], "RLum.Analysis") && length(object[[x]]@records) == 0)
                   return(NULL)
 
                 get_RLum(object[[x]], ...)
@@ -103,7 +103,7 @@ setMethod("get_RLum",
 
               ##first set all empty objects to NULL ... for RLum.Analysis objects
               selection <- lapply(1:length(selection), function(x){
-                if(class(selection[[x]]) == "RLum.Analysis" && length(selection[[x]]@records) == 0){
+                if(inherits(selection[[x]], "RLum.Analysis") && length(selection[[x]]@records) == 0){
                   return(NULL)
 
                 }else{
