@@ -1,13 +1,13 @@
 #' Import Risø BIN/BINX-files into R
 #'
-#' Import a *.bin or a *.binx file produced by a Risoe DA15 and DA20 TL/OSL
+#' Import a *.bin or a *.binx file produced by a Risø DA15 and DA20 TL/OSL
 #' reader into R.
 #'
 #' The binary data file is parsed byte by byte following the data structure
 #' published in the Appendices of the Analyst manual p. 42.
 #'
 #' For the general BIN/BINX-file structure, the reader is referred to the
-#' Risoe website: [http://www.nutech.dtu.dk/]()
+#' Risø website: [https://www.fysik.dtu.dk]()
 #'
 #' @param file [character] or [list] (**required**): path and file name of the
 #' BIN/BINX file (URLs are supported). If input is a `list` it should comprise
@@ -16,7 +16,7 @@
 #' the function tries to detect and import all BIN/BINX files found in the directory.
 #'
 #' @param show.raw.values [logical] (*with default*):
-#' shows raw values from BIN file for `LTYPE`, `DTYPE` and `LIGHTSOURCE` without
+#' shows raw values from BIN-file for `LTYPE`, `DTYPE` and `LIGHTSOURCE` without
 #' translation in characters. Can be provided as `list` if `file` is a `list`.
 #'
 #' @param n.records [raw] (*optional*):
@@ -25,13 +25,13 @@
 #' Can be provided as `list` if `file` is a `list`.
 #'
 #' @param zero_data.rm [logical] (*with default*):
-#' remove erroneous data with no count values. As such data are usally not
+#' remove erroneous data with no count values. As such data are usually not
 #' needed for the subsequent data analysis they will be removed by default.
 #' Can be provided as `list` if `file` is a `list`.
 #'
 #' @param duplicated.rm [logical] (*with default*):
 #' remove duplicated entries if `TRUE`. This may happen due to an erroneous
-#' produced BIN/BINX-file. This option compares only predeccessor and successor.
+#' produced BIN/BINX-file. This option compares only predecessor and successor.
 #' Can be provided as `list` if `file` is a `list`.
 #'
 #' @param position [numeric] (*optional*):
@@ -78,8 +78,9 @@
 #' Returns an S4 [Risoe.BINfileData-class] object containing two
 #' slots:
 #'
-#' \item{METADATA}{A [data.frame] containing all variables stored in the bin-file.}
-#' \item{DATA}{A [list] containing a numeric [vector] of the measured data. The ID corresponds to the record ID in METADATA.}
+#' \item{METADATA}{A [data.frame] containing all variables stored in the BIN-file.}
+#' \item{DATA}{A [list] containing a numeric [vector] of the measured data.
+#' The ID corresponds to the record ID in METADATA.}
 #'
 #' If `fastForward = TRUE` a list of [RLum.Analysis-class] object is returned. The
 #' internal coercing is done using the function [Risoe.BINfileData2RLum.Analysis]
@@ -88,13 +89,13 @@
 #' The function works for BIN/BINX-format versions 03, 04, 05, 06, 07 and 08. The
 #' version number depends on the used Sequence Editor.
 #'
-#' **ROI data sets introduced with BIN-file version 8 are not supported and skipped durint import.**
+#' **ROI data sets introduced with BIN-file version 8 are not supported and skipped during import.**
 #'
-#' @section Function version: 0.16.2
+#' @section Function version: 0.16.5
 #'
 #'
 #' @author
-#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)\cr
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)\cr
 #' Margret C. Fuchs, HZDR Freiberg, (Germany) \cr
 #' based on information provided by Torben Lapp and Karsten Bracht Nielsen (Risø DTU, Denmark)
 #'
@@ -104,20 +105,18 @@
 #' [utils::txtProgressBar], [list.files]
 #'
 #'
-#' @references
-#' DTU Nutech, 2016. The Squence Editor, Users Manual, February, 2016.
-#' [http://www.nutech.dtu.dk/english/products-and-services/radiation-instruments/tl_osl_reader/manuals]()
+#'@references
+#'DTU Nutech, 2016. The Sequence Editor, Users Manual, February, 2016.
+#'[https://www.fysik.dtu.dk]()
 #'
 #'
-#' @keywords IO
+#'@keywords IO
 #'
-#' @examples
+#'@examples
 #'
-#' ##(1) import Risoe BIN-file to R (uncomment for usage)
-#'
-#' #FILE <- file.choose()
-#' #temp <- read_BIN2R(FILE)
-#' #temp
+#'file <- system.file("extdata/BINfile_V8.binx", package = "Luminescence")
+#'temp <- read_BIN2R(file)
+#'temp
 #'
 #' @md
 #' @export
@@ -143,11 +142,10 @@ read_BIN2R <- function(
   # with that many file can be read in at the same time
   # Option (b): The input is just a path, the function tries to grep ALL BIN/BINX files in the
   # directory and import them, if this is detected, we proceed as list
-
   if (is.character(file)) {
     if (is.null(pattern)) {
       ##If this is not really a path we skip this here
-      if (dir.exists(file) & length(dir(file)) > 0) {
+      if (all(dir.exists(file)) & length(dir(file)) > 0) {
         if (verbose) {
           cat(
             "[read_BIN2R()] Directory detected, trying to extract '*.bin'/'*.binx' files ...\n"
@@ -160,13 +158,10 @@ read_BIN2R <- function(
           recursive = FALSE,
           pattern = "\\.bin*",
           full.names = TRUE,
-          ignore.case = TRUE
-        ))
-
+          ignore.case = TRUE))
 
       }
 
-
     }else if(dir.exists(file)){
       file <- as.list(list.files(file, pattern = pattern, full.names = TRUE, recursive = TRUE))
 
@@ -174,9 +169,7 @@ read_BIN2R <- function(
 
   }
 
-
   if (is.list(file)) {
-
     ##extend list of parameters
 
     ##position
@@ -329,11 +322,11 @@ read_BIN2R <- function(
   ##check if file is a BIN or BINX file
   if(!(TRUE%in%(c("BIN", "BINX", "bin", "binx")%in%sub(pattern = "%20", replacement = "", x = tail(
     unlist(strsplit(file, split = "\\.")), n = 1), fixed = TRUE)))){
-
     try(
       stop(
         paste0("[read_BIN2R()] '", file,"' is not a file or not of type 'BIN' or 'BINX'! Skipped!"),
         call. = FALSE))
+    con <- NULL
     return(NULL)
 
   }
@@ -353,17 +346,22 @@ read_BIN2R <- function(
   # Short file parsing to get number of records -------------------------------------------------
 
   #open connection
-  con<-file(file, "rb")
+  con <- file(file, "rb")
 
   ##get information about file size
   file.size <- file.info(file)
 
+  ##skip if zero-byte
+  if(file.size$size == 0){
+    message(paste0("[read_BIN2R()] ", basename(file)," is a zero-byte file, skipped!"))
+    return(NULL)
+  }
+
   ##read data up to the end of con
 
   ##set ID
   temp.ID <- 0
 
-
   ##start for BIN-file check up
   while(length(temp.VERSION<-readBin(con, what="raw", 1, size=1, endian="little"))>0) {
 
@@ -393,7 +391,7 @@ read_BIN2R <- function(
 
       }else{
         ##show error message
-        error.text <- paste("[read_BIN2R()] Found BIN/BINX-format version (",temp.VERSION,") is not supported or the BIN/BINX-file is broken.! Supported version numbers are: ",paste(VERSION.supported,collapse=", "),".",sep="")
+        error.text <- paste("[read_BIN2R()] Found BIN/BINX-format version (",temp.VERSION,") is not supported or the BIN/BINX-file is broken! Supported version numbers are: ",paste(VERSION.supported,collapse=", "),".",sep="")
 
         ##show error
         stop(error.text, call. = FALSE)
@@ -633,7 +631,7 @@ read_BIN2R <- function(
 
 
   #set variable for DPOINTS handling
-  results.DATA<-list()
+  results.DATA <- list()
 
   ##set list for RESERVED values
   results.RESERVED <- rep(list(list()), n.length)
@@ -655,9 +653,9 @@ read_BIN2R <- function(
   ##output
   if(verbose){cat(paste("\n[read_BIN2R()]\n\t >> ",file,sep=""), fill=TRUE)}
 
-  ##set progressbar
+  ##set progress bar
   if(txtProgressBar & verbose){
-    pb<-txtProgressBar(min=0,max=file.size$size, char="=", style=3)
+    pb <- txtProgressBar(min=0 ,max = file.size$size, char="=", style=3)
   }
 
   ##read data up to the end of con
@@ -667,9 +665,8 @@ read_BIN2R <- function(
 
 
   # LOOP --------------------------------------------------------------------
-
   ##start loop for import BIN data
-  while(length(temp.VERSION<-readBin(con, what="raw", 1, size=1, endian="little"))>0) {
+  while(length(temp.VERSION <- readBin(con, what="raw", 1, size=1, endian="little"))>0) {
 
     ##force version number
     if(!is.null(forced.VersionNumber)){
@@ -682,16 +679,13 @@ read_BIN2R <- function(
       ##show error message
       error.text <- paste("[read_BIN2R()] BIN-format version (",temp.VERSION,") of this file is currently not supported! Supported version numbers are: ",paste(VERSION.supported,collapse=", "),".",sep="")
 
-      stop(error.text)
+      stop(error.text, call. = FALSE)
 
     }
 
     ##print record ID for debugging purposes
     if(verbose){
       if(show.record.number == TRUE){
-
-
-
         cat(temp.ID,",", sep = "")
         if(temp.ID%%10==0){
           cat("\n")
@@ -701,13 +695,13 @@ read_BIN2R <- function(
 
 
     #empty byte position
-    EMPTY<-readBin(con, what="raw", 1, size=1, endian="little")
+    EMPTY <- readBin(con, what="raw", 1, size=1, endian="little")
 
     # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     # BINX FORMAT SUPPORT -----------------------------------------------------
     if(temp.VERSION == 05 | temp.VERSION == 06 | temp.VERSION == 07 | temp.VERSION == 08){
 
-      ##(1) Header size and strucutre
+      ##(1) Header size and structure
       ##LENGTH, PREVIOUS, NPOINTS, LTYPE
       temp <- readBin(con, what="int", 3, size=4, endian="little")
 
@@ -720,24 +714,32 @@ read_BIN2R <- function(
       if(temp.VERSION == 08){
         temp.RECTYPE <- readBin(con, what="int", 1, size=1, endian="little", signed = FALSE)
         if(temp.RECTYPE != 0 & temp.RECTYPE != 1){
-          ##jump to the next record by stepping the record length minus the alread read bytes
+          ##jump to the next record by stepping the record length minus the already read bytes
           STEPPING <- readBin(con, what = "raw", size = 1, n = temp.LENGTH - 15)
 
           if(temp.RECTYPE == 128){
-            warning(paste0("[read_BIN2R()] ROI definition in data set #",temp.ID+1, "detected, but currently not supported, record skipped!", call. = FALSE))
+            warning(paste0("[read_BIN2R()] ROI definition in data set #",temp.ID+1, " detected, but currently not supported, record skipped!"), call. = FALSE)
 
           }else{
             if(!ignore.RECTYPE){
-              stop(paste0("[read_BIN2R()] Byte RECTYPE = ",temp.RECTYPE," is not supported in record #",temp.ID+1,"! Check your BIN-file!"), call. = FALSE)
+              stop(
+                paste0("[read_BIN2R()] Byte RECTYPE = ",temp.RECTYPE," is not supported in record #",temp.ID+1,"!
+                       Check your BIN/BINX file!"), call. = FALSE)
 
             }else{
-              if(verbose) cat(paste0("\n[read_BIN2R()] Byte RECTYPE = ",temp.RECTYPE," is not supported in record #",temp.ID+1,", record skipped!"))
-              temp.ID <- temp.ID + 1
+              if(verbose)
+                cat(paste0("\n[read_BIN2R()] Byte RECTYPE = ",temp.RECTYPE," is not supported in record #",temp.ID+1,", record skipped!"))
+
             }
 
           }
 
-          next
+          ## update and jump to next record, to avoid further trouble
+          ## we set the VERSION to NA and remove it later, otherwise we
+          ## break expected functionality
+          temp.ID <- temp.ID + 1
+          results.METADATA[temp.ID,`:=` (VERSION = NA)]
+          next()
         }
       }
 
@@ -840,9 +842,9 @@ read_BIN2R <- function(
       DATE_SIZE<-readBin(con, what="int", 1, size=1, endian="little")
 
       ##date size corrections for wrong date formats; set n to 6 for all values
-      ##accoording the handbook of Geoff Duller, 2007
+      ##according the handbook of Geoff Duller, 2007
       DATE_SIZE<-6
-      temp.DATE<-readChar(con, DATE_SIZE, useBytes=TRUE)
+      temp.DATE <- readChar(con, DATE_SIZE, useBytes = TRUE)
 
 
       ##(4) Analysis
@@ -1056,17 +1058,20 @@ read_BIN2R <- function(
 
 
       ##POSITION
-      temp.POSITION<-readBin(con, what="int", 1, size=1, endian="little")
+      temp.POSITION <- readBin(
+        con, what="int", 1, size=1, endian="little", signed = FALSE)
 
       ##RUN
-      temp.RUN<-readBin(con, what="int", 1, size=1, endian="little")
+      temp.RUN <- readBin(
+        con, what="int", 1, size=1, endian="little", signed = FALSE)
 
       ##TIME
-      TIME_SIZE<-readBin(con, what="int", 1, size=1, endian="little")
+      TIME_SIZE <- readBin(
+        con, what="int", 1, size=1, endian="little")
 
 
       ##time size corrections for wrong time formats; set n to 6 for all values
-      ##accoording the handbook of Geoff Duller, 2007
+      ##according to the handbook of Geoff Duller, 2007
       TIME_SIZE<-6
       temp.TIME<-readChar(con, TIME_SIZE, useBytes=TRUE)
 
@@ -1232,7 +1237,7 @@ read_BIN2R <- function(
 
 
     }else{
-      stop("[read_BIN2R()] Unsupported BIN/BINX-file version.")
+      stop("[read_BIN2R()] Unsupported BIN/BINX-file version.", call. = FALSE)
 
     }
 
@@ -1241,7 +1246,7 @@ read_BIN2R <- function(
     ## ==========================================================================#
 
     #SET UNIQUE ID
-    temp.ID <- temp.ID+1
+    temp.ID <- temp.ID + 1
 
      ##update progress bar
     if(txtProgressBar & verbose){
@@ -1364,6 +1369,9 @@ read_BIN2R <- function(
   ##close
   if(txtProgressBar & verbose){close(pb)}
 
+  ## remove NA values created by skipping records
+  results.METADATA <- na.omit(results.METADATA, cols = "VERSION")
+
   ##output
   if(verbose){cat(paste("\t >> ",temp.ID," records have been read successfully!\n\n", sep=""))}
 
@@ -1398,7 +1406,7 @@ read_BIN2R <- function(
 
   ##check for position that have no data at all (error during the measurement)
   if(zero_data.rm){
-    zero_data.check <- which(sapply(results.DATA, length) == 0)
+    zero_data.check <- which(vapply(results.DATA, length, numeric(1)) == 0)
 
     ##remove records if there is something to remove
     if(length(zero_data.check) != 0){
@@ -1413,7 +1421,7 @@ read_BIN2R <- function(
           "\n[read_BIN2R()] ", length(zero_data.check), " zero data records detected and removed: ",
           paste(zero_data.check, collapse = ", "),
           ". \n\n >> Record index re-calculated."
-        )
+        ), call. = FALSE
       )
 
     }
